==> corearchiver-2.8.0.tar.gz: corearchiver-v2.8.0/main.cpp <==
/*
    *
    * This file is a part of CoreArchiver.
    * Archive manager for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, vsit http://www.gnu.org/licenses/.
    *
*/

#include <QApplication>
#include <QCommandLineOption>
#include <QCommandLineParser>
#include <QDebug>

#include "corearchiver.h"


int main(int argc, char *argv[])
{
#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
    QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
#endif

    QApplication app(argc, argv);
    app.setQuitOnLastWindowClosed(true);

    // Set application info
    app.setOrganizationName("CuboCore");
    app.setApplicationName("CoreArchiver");

    QCommandLineParser parser;
    parser.addHelpOption();
    parser.addVersionOption();

    QList<QCommandLineOption> options;

    options << QCommandLineOption(QStringList() << "a", "Archive files")
            << QCommandLineOption(QStringList() << "e", "Extract Archive");

    parser.addOptions(options);

    const QString files = "[FILE1, FILE2,...]";
    parser.addPositionalArgument("files", files, files);
    parser.process(app);

    QStringList args = parser.positionalArguments();
    QStringList paths;

    foreach (QString arg, args) {
        QFileInfo info(arg);
        paths.push_back(info.absoluteFilePath());
    }

    corearchiver *carc = new corearchiver;

    if (parser.isSet("a")) {
        // Create sendFiles( QStringList ) function for sending paths
        carc->sendFiles(paths, true);
        qDebug() << "Archiving setted...\n" << paths;
    } else if (parser.isSet("e")) {
        // Create sendFiles( QStringList ) function for sending paths
        carc->sendFiles(paths, false);
        qDebug() << "Extracting setted...\n" << paths;
    } else {
        qDebug() << "Something went wrong.";
    }

    carc->show();

    return app.exec();
}

==> corearchiver-4.1.0.tar.gz: corearchiver-v4.1.0/main.cpp <==
/*
    *
    * This file is a part of CoreArchiver.
    * Archive manager for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, vsit http://www.gnu.org/licenses/.
    *
*/

#include <QApplication>
#include <QCommandLineOption>
#include <QCommandLineParser>
#include <QDebug>

#include "corearchiver.h"


int main(int argc, char *argv[])
{
#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
    QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
#endif

    QApplication app(argc, argv);
    app.setQuitOnLastWindowClosed(true);

    // Set application info
    app.setOrganizationName("CuboCore");
    app.setApplicationName("CoreArchiver");

    QCommandLineParser parser;
    parser.addHelpOption();
    parser.addVersionOption();

    QList<QCommandLineOption> options;

    options << QCommandLineOption(QStringList() << "a" << "add", "Archive files")
            << QCommandLineOption(QStringList() << "e" << "extract", "Extract Archive");

    parser.addOptions(options);

    const QString files = "[FILE1, FILE2,...]";
    parser.addPositionalArgument("files", files, files);
    parser.process(app);

    QStringList args = parser.positionalArguments();
    QStringList paths;

    foreach (QString arg, args) {
        QFileInfo info(arg);
        paths.push_back(info.absoluteFilePath());
    }

    corearchiver *carc = new corearchiver;
    carc->sendFiles(paths);
    carc->show();

    return app.exec();
}
